"use client";
import React, { useEffect, useState, useRef } from "react";
import PaginationComponent from "../Pagination";
import Image from "next/image";
import Link from "next/link";
import { useSearchParams } from "next/navigation";
// add slider
import { Navigation, Pagination, Scrollbar, A11y } from "swiper/modules";
import arrow_right from "@/assets/arrowicon.svg";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
// import "./style.css"

import {
  FaceBookIcon,
  InstaIcon,
  LocationIcon,
  TwitterIcon,
  WhatsAppIcon,
  WhiteLinkdInIcon,
} from "@/components/Icons";

export const JewelleryListingCard = ({ initialData }) => {
  const searchParams = useSearchParams();
  const [currentPage, setCurrentPage] = useState(1);
  const [data, setData] = useState(initialData);
  const totalPages = 4; // Total number of pages

  // slider
  const [preious, setPreious] = useState(false);
  const [next, setNext] = useState(false);
  const swiperRefs = useRef({});
  //  const swiperRefs = useRef<{ [key: string]: SwiperInstance }>({});

  const handlePrevSlide = (id) => {
    console.log("hello");
    if (swiperRefs.current[id]) {
      swiperRefs.current[id].slidePrev();
    }
  };
  const handleNextSlide = (id) => {
    if (swiperRefs.current[id]) {
      swiperRefs.current[id].slideNext();
    }
  };

  const modifiedData = [
    ...data.slice(0, 3),
    { isAd: true }, // Adding a placeholder object for the ad
    ...data.slice(3),
  ];

  const handlePageChange = (pageNumber) => {
    setCurrentPage(pageNumber);
  };

  useEffect(() => {
    const fetchData = async () => {
      const params = new URLSearchParams(searchParams);
      const res = await fetch(
        `${
          process.env.NEXT_PUBLIC_BASE_URL
        }/jewelry/filter?${params.toString()}`
      );
      const result = await res.json();
      setData(result);
    };
    fetchData();
  }, [searchParams]);

  return (
    <div className="flex flex-col w-full lg:me-20 gap-6">
      {modifiedData.map((item, index) => {
        console.log("images are ", item.pictures);
        if (item.isAd) {
          return (
            <figure key={`ad-${index}`} className="w-full">
              <Image
                src="/assets/images/ads.png"
                className="w-full min-h-[115px] rounded object-cover"
                height={168}
                width={955}
                alt="ads"
              />
            </figure>
          );
        }
        return (
          <div
            key={item._id}
            className={`flex flex-col sm:flex-row custom-shadow rounded gap-4 md:gap-11 p-5 items-center ${
              index === 3 ? "mt-[180px]" : ""
            }`}
          >
            <div
              className="w-full sm:w-1/2 relative"
              style={{ maxWidth: "350px" }}
            >
              {/* Previous arrow */}
              <div
                onClick={() => handlePrevSlide(item._id)}
                className={`absolute top-[30%] left-10 z-40 h-[100px] w-[25px] flex items-center justify-center ${
                  preious ? "bg-white" : "bg-[#FFFFFF]"
                }`}
              >
                <div className=" px-2 py-1 rounded">
                  <img
                    src={"/icons/golden-arrow-previous.png"}
                    alt="previous"
                    className=""
                  />
                </div>
              </div>
              {/* Image slider */}
              <Swiper
                spaceBetween={0}
                slidesPerView={1}
                hashNavigation={{
                  watchState: true,
                }}
                loop={true}
                pagination={{ clickable: true }}
                scrollbar={{ draggable: true }}
                style={{ maxWidth: "312px", width: "100%", height: "250px" }} // Adjusted height to match your design
                modules={[Navigation, Pagination, Scrollbar, A11y]}
                onSwiper={(swiper) => {
                  swiperRefs.current[item._id] = swiper;
                }}
              >
                {item.pictures?.images.map((image, imgIndex) => (
                  <SwiperSlide key={imgIndex}>
                    <Link href={`jewelry/${item._id}`}>
                      <Image
                        className="rounded-lg !w-[314px] !h-[250px]"
                        src={image.url}
                        height={253}
                        width={314}
                        alt={item.title}
                      />
                    </Link>
                  </SwiperSlide>
                ))}
              </Swiper>
              {/* Next arrow */}
              <div
                onClick={() => handleNextSlide(item._id)}
                className={`absolute top-[30%] right-10 z-40 h-[100px] w-[25px] flex items-center justify-center ${
                  next ? "bg-white" : "bg-[#FFFFFF]"
                }`}
              >
                <div className="px-2 py-1 rounded">
                  <img
                    src={"/icons/golden-arrow-previous.png"}
                    className="transform rotate-180"
                    alt="next"
                  />
                </div>
              </div>
            </div>

            <div>
              <p className="text-reefGold text-sm ">Necklace</p>
              <Link href={`jewelry/${item._id}`}>
                <h2 className="fs-40 mb-2 font-semibold leading-none capitalize">
                  {item.title}
                </h2>
              </Link>
              <p className="text-reefGold mb-3">{item.price} USD</p>
              <div className="flex gap-6 items-center mb-3">
                <p>
                  <span className="font-medium text-lg">Age:</span> {item.age}
                </p>
                <p>
                  <span className="font-medium text-lg">Grams:</span>{" "}
                  {item.weight}gm
                </p>
              </div>
              <div className="flex gap-3 items-center mb-3">
                <LocationIcon className="text-reefGold" />
                <p>{item.country}</p>
              </div>
              <div>
                <p className="mb-3">Share With:</p>
                <div className="flex gap-3">
                  <Link href="#">
                    <FaceBookIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <InstaIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhiteLinkdInIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <TwitterIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhatsAppIcon className="h-[21px] w-[21px]" />
                  </Link>
                </div>
              </div>
            </div>
          </div>
        );
      })}
      <PaginationComponent
        currentPage={currentPage}
        totalPages={totalPages}
        onPageChange={handlePageChange}
      />
    </div>
  );
};
